'______________________________________________________________________________________

'                                                          A D O   M E T H O D S
'                                                                Ron Kessler
'                                                             Created 4/27/07
'_____________________________________________________________________________________

'Updated 4/27/07
'This class manages the major ADO methods to make the program more OOP in design!

'Most methods are declared as Shared so you don't have to instantiate an object.

Imports System.Data
Imports System.Data.OleDb

Public Class ADOMethods

    Public Shared Function MakeConnection() As OleDbConnection

        '---Create a new datasource and point to the db. Use DATA | Add new DataSource. 
        '     This will store the conn string in the app.config file. Look in My Project |Settings to see it also.
        '1---Then you can delete the datasource...find the .XSD dataset stuff and delete them.
        '---Refer to the conn string like this:
        Dim connString As String = My.Settings.customersConnectionString.ToString
        Dim conn As OleDbConnection = New OleDbConnection(connString)
        Return conn

    End Function

    Public Shared Function MakeDAcommands(ByVal dataAdapter As OleDbDataAdapter, ByVal tableName As String) As OleDbCommandBuilder

        '---the Commandbuilder adds the insert, update, and delete capabilities to the dataAdapter.
        '   I also have to the the dataAdapter to map/add a table to it's collection.
        Dim myCommandBuilder As New OleDbCommandBuilder(dataAdapter)
        dataAdapter.TableMappings.Add("Table", tableName)
        Return myCommandBuilder

    End Function

    Public Shared Sub FillTheGrid(ByVal myDataSet As DataSet, ByVal sqlString As String, ByVal tableName As String)

        '---this sub takes the sqlString, table name and the dataset and fills the dataset
        Dim conn As OleDbConnection = ADOMethods.MakeConnection()

        Try
            '---be sure to declare these in this order
            Using dataAdapter As OleDbDataAdapter = New OleDbDataAdapter(sqlString, conn)

                Dim DACommands As OleDbCommandBuilder = ADOMethods.MakeDAcommands(dataAdapter, tableName) 'add update/insert/delete to DA
                dataAdapter.Fill(myDataSet, tableName)

            End Using

        Catch ex As OleDbException

            MessageBox.Show("I could not read the database." + ex.Message, "System Message", _
                        MessageBoxButtons.OK, MessageBoxIcon.Error)

        Finally
            conn.Close()    'just to be sure!

        End Try

    End Sub

    Public Shared Sub DoUpdate(ByVal myDataSet As DataSet, ByVal sqlString As String, ByVal tableName As String)

        '---we use this to save changes if any were made when they choose Save from the menu
        Dim conn As OleDbConnection = ADOMethods.MakeConnection()

        If myDataSet.HasChanges() Then           'no changes? Then why bother.

            Try

                conn.Open()
                Using dataAdapter As OleDbDataAdapter = New OleDbDataAdapter(sqlString, conn)

                    Dim DACommands As OleDbCommandBuilder = ADOMethods.MakeDAcommands(dataAdapter, tableName)
                    dataAdapter.Update(myDataSet)
                    MessageBox.Show("Your data has been updated.", "System Message", _
                        MessageBoxButtons.OK, MessageBoxIcon.Information)
                End Using

            Catch ex As DataException

                MessageBox.Show("An error occurred." + ex.Message, "Database Error", _
                    MessageBoxButtons.OK, MessageBoxIcon.Error)

            Finally
                conn.Close()
            End Try
        Else
            MessageBox.Show("You have not made any changes yet.", "System Message", MessageBoxButtons.OK, MessageBoxIcon.Information)
        End If
    End Sub
End Class
